@@ -8,7 +8,7 @@ use parent 'Exporter';
 
 use Sub::Quote;
 
-our $VERSION = '0.33'; # VERSION
+our $VERSION = '0.34'; # VERSION
 
 our @EXPORT = qw(
     alt
@@ -192,11 +192,11 @@ Data::Object::Role::Syntax - DSL for Declaring Roles for Perl 5
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
-    package Person;
+    package Persona;
 
     use Data::Object::Role;
     use Data::Object::Role::Syntax;
